Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/__init__.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/__init__.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/__init__.py	(revision 12371)
@@ -2,7 +2,7 @@
 """
 # Make this a package.
-from ikobacustom.skeleton.documents.document import SkeletonDocument
+from ikobacustom.pcn.documents.document import PCNDocument
 
 __all__ = [
-    'SkeletonDocument',
+    'PCNDocument',
     ]
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/document.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/document.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/document.py	(revision 12371)
@@ -24,28 +24,28 @@
 from waeup.ikoba.utils.helpers import attrs_to_fields
 from waeup.ikoba.documents.document import PublicDocumentBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.documents.interfaces import IPCNDocument
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class SkeletonDocument(PublicDocumentBase):
+class PCNDocument(PublicDocumentBase):
     """This is a document.
     """
-    grok.implements(ISkeletonDocument)
-    grok.provides(ISkeletonDocument)
+    grok.implements(IPCNDocument)
+    grok.provides(IPCNDocument)
 
-SkeletonDocument = attrs_to_fields(SkeletonDocument)
+PCNDocument = attrs_to_fields(PCNDocument)
 
 
-class SkeletonDocumentFactory(grok.GlobalUtility):
+class PCNDocumentFactory(grok.GlobalUtility):
     """A factory for documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonDocument')
+    grok.name(u'waeup.PCNDocument')
     title = u"Create a new document.",
-    description = u"This factory instantiates new skeleton documents."
+    description = u"This factory instantiates new pcn documents."
 
     def __call__(self, *args, **kw):
-        return SkeletonDocument(*args, **kw)
+        return PCNDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonDocument)
+        return implementedBy(PCNDocument)
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/tests/test_browser.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/tests/test_browser.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/tests/test_browser.py	(revision 12371)
@@ -27,8 +27,8 @@
 from zope.interface.verify import verifyObject, verifyClass
 from waeup.ikoba.documents.tests.test_batching import DocumentImportExportSetup
-from ikobacustom.skeleton.documents.document import SkeletonDocument
-from ikobacustom.skeleton.documents.export import SkeletonDocumentExporter
-from ikobacustom.skeleton.documents.batching import SkeletonDocumentProcessor
-from ikobacustom.skeleton.testing import FunctionalLayer
+from ikobacustom.pcn.documents.document import PCNDocument
+from ikobacustom.pcn.documents.export import PCNDocumentExporter
+from ikobacustom.pcn.documents.batching import PCNDocumentProcessor
+from ikobacustom.pcn.testing import FunctionalLayer
 
 
@@ -38,5 +38,5 @@
 
     def setup_for_export(self):
-        document = SkeletonDocument()
+        document = PCNDocument()
         document.document_id = u'DOC1'
         document.title = u'My first document'
@@ -49,5 +49,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonDocumentExporter()
+        exporter = PCNDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -55,9 +55,9 @@
             'class_name,description,document_id,history,state,title,'
             'users_with_local_roles\r\n'
-            'SkeletonDocument,,DOC1,'
+            'PCNDocument,,DOC1,'
             '[u\'2014-12-21 23:27:15 WAT - Document created by system\'],'
             'created,My first document,[]\r\n')
         # We can import the same file.
-        processor = SkeletonDocumentProcessor()
+        processor = PCNDocumentProcessor()
         result = processor.doImport(
             self.outfile,
@@ -79,5 +79,5 @@
         self.assertEqual(num_fail,0)
         # We can import the same file in update mode.
-        processor = SkeletonDocumentProcessor()
+        processor = PCNDocumentProcessor()
         result = processor.doImport(
             self.outfile,
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/tests/test_document.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/tests/test_document.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/tests/test_document.py	(revision 12371)
@@ -17,5 +17,5 @@
 ##
 """
-Tests for skeleton documents.
+Tests for pcn documents.
 """
 from zope.interface.verify import verifyClass, verifyObject
@@ -23,9 +23,9 @@
 from waeup.ikoba.documents.container import DocumentsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.documents.document import SkeletonDocument
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
+from ikobacustom.pcn.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.pcn.documents.document import PCNDocument
+from ikobacustom.pcn.documents.interfaces import IPCNDocument
 
-class SkeletonDocumentTestCase(FunctionalTestCase):
+class PCNDocumentTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
@@ -35,15 +35,15 @@
         self.assertTrue(
             verifyClass(
-                ISkeletonDocument, SkeletonDocument)
+                IPCNDocument, PCNDocument)
             )
         self.assertTrue(
             verifyObject(
-                ISkeletonDocument, SkeletonDocument())
+                IPCNDocument, PCNDocument())
             )
         return
 
-    def test_addSkeletonDocument(self):
+    def test_addPCNDocument(self):
         container = DocumentsContainer()
-        document = createObject(u'waeup.SkeletonDocument')
+        document = createObject(u'waeup.PCNDocument')
         document.document_id = u'DOC1'
         container.addDocument(document)
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/utils.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/utils.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/utils.py	(revision 12371)
@@ -19,8 +19,8 @@
 """
 from waeup.ikoba.documents.utils import DocumentsUtils
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentsUtils(DocumentsUtils):
+class PCNDocumentsUtils(DocumentsUtils):
     """A collection of methods subject to customization.
     """
@@ -29,5 +29,5 @@
         'PDFDocument': _('PDF Document'),
         'HTMLDocument': _('HTML Document'),
-        'SkeletonDocument': _('Skeleton Document'),
+        'PCNDocument': _('PCN Document'),
         }
 

Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/batching.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/batching.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/batching.py	(revision 12371)
@@ -16,20 +16,20 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Batch processing for skeleton documents.
 """
 import grok
 from waeup.ikoba.documents.batching import DocumentProcessorBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.documents.interfaces import IPCNDocument
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentProcessor(DocumentProcessorBase):
-    """A batch processor for ISkeletonDocument objects.
+class PCNDocumentProcessor(DocumentProcessorBase):
+    """A batch processor for IPCNDocument objects.
     """
-    util_name = 'skeletondocumentprocessor'
+    util_name = 'pcndocumentprocessor'
     grok.name(util_name)
 
-    name = _('Skeleton Document Processor')
-    iface = ISkeletonDocument
+    name = _('PCN Document Processor')
+    iface = IPCNDocument
 
-    factory_name = 'waeup.SkeletonDocument'
+    factory_name = 'waeup.PCNDocument'
@@ -16,20 +16,20 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Batch processing for skeleton documents.
+"""Batch processing for pcn documents.
 """
 import grok
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/export.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/export.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/export.py	(revision 12371)
@@ -16,17 +16,17 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Exporters for skeleton documents.
 """
 import grok
 from waeup.ikoba.documents.export import DocumentExporterBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.documents.interfaces import IPCNDocument
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentExporter(DocumentExporterBase):
+class PCNDocumentExporter(DocumentExporterBase):
     """Exporter for documents.
     """
-    grok.name('skeletondocuments')
-    iface = ISkeletonDocument
-    class_name = 'SkeletonDocument'
-    title = _(u'Skeleton Documents')
+    grok.name('pcndocuments')
+    iface = IPCNDocument
+    class_name = 'PCNDocument'
+    title = _(u'PCN Documents')
@@ -16,17 +16,17 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Exporters for skeleton documents.
+"""Exporters for pcn documents.
 """
 import grok
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/interfaces.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/documents/interfaces.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/documents/interfaces.py	(revision 12371)
@@ -17,9 +17,9 @@
 ##
 from waeup.ikoba.documents.interfaces import IPublicDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class ISkeletonDocument(IPublicDocument):
-    """A representation of a skeleton document.
+class IPCNDocument(IPublicDocument):
+    """A representation of a pcn document.
 
     """